Package: SubcellularSpatialData
Title: Annotated spatial transcriptomics datasets from 10x Xenium,
        NanoString CosMx and BGI STOmics.
Version: 1.9.0
Authors@R: c(
            person(given = "Dharmesh D.",
                   family = "Bhuva",
                   role = c("aut", "cre"),
                   email = "dharmesh.bhuva@adelaide.edu.au",
                   comment = c(ORCID = "0000-0002-6398-9157"))
            )
Description: This is a data package that hosts annotated sub-cellular localised datasets from the STOmics, Xenium and CosMx platforms. Specifically, it hosts datasets analysed in the publication Bhuva et. al, 2024 titled "Library size confounds biology in spatial transcriptomics data". Raw transcript detections are hosted and functions to convert them to SpatialExperiment objects have been implemented.
biocViews: ExperimentHub, SpatialData, Homo_sapiens_Data,
        Mus_musculus_Data, LungCancerData
License: GPL (>= 3)
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
URL: https://davislaboratory.github.io/SubcellularSpatialData
BugReports: https://github.com/DavisLaboratory/SubcellularSpatialData/issues
Imports: dplyr, hexbin, Matrix, SpatialExperiment, stats
NeedsCompilation: no
VignetteBuilder: knitr
Suggests: BiocStyle, ExperimentHub, ggplot2, knitr, prettydoc,
        rmarkdown, testthat (>= 3.0.0)
Depends: R (>= 4.4)
LazyData: false
Config/testthat/edition: 3
git_url: https://git.bioconductor.org/packages/SubcellularSpatialData
git_branch: devel
git_last_commit: 7a2f671
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-30
Packaged: 2026-04-30 16:02:02 UTC; biocbuild
Author: Dharmesh D. Bhuva [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6398-9157>)
Maintainer: Dharmesh D. Bhuva <dharmesh.bhuva@adelaide.edu.au>
